<?php
/**
 * Smart Child Theme functions.php
 *
 * Please refer to smart/functions.php and smart/inc/theme.php for framework setup.
 */

/**
 * Enqueue the CSS. Please note the CSS order is as follows:
 *
 *  - smart/style.css
 *  - smart/css/skin-XYZ.css
 *  - smart-child/style.css
 *  - Inline Custom CSS from Customize
 */
function my_enqueue_child_style() {
	wp_enqueue_style(
		'smart-mag-child', 
		get_stylesheet_uri(),
		['smartmag-core'],
		'1.0'
	);
}

// Enqueue child theme CSS after parent is registered.
add_action('bunyad_register_assets', 'my_enqueue_child_style');

// Alternatively, you may use:
// add_action('wp_enqueue_style', 'my_enqueue_child_style', 11);

// OR, to enqueue after Customizer Additional CSS:
// add_action('wp_head', 'my_enqueue_child_style', 110);

// Remove Link rel=shortlink from http headers
add_filter('after_setup_theme', 'my_disable_rel_shortlink');


// ******************** remove rel_shortlink from headers ********************** //
function my_disable_rel_shortlink() 
	{remove_action( 'template_redirect', 'wp_shortlink_header', 11); }


// ******************** remove yoast breadcrumbs Structured Data from yoast schema ********************** //
add_filter( 'wpseo_schema_graph_pieces', 'remove_breadcrumbs_from_schema', 11, 2 );
add_filter( 'wpseo_schema_webpage', 'remove_breadcrumbs_property_from_webpage', 11, 1 );

/**
 * Removes the breadcrumb graph pieces from the schema collector.
 *
 * @param array  $pieces  The current graph pieces.
 * @param string $context The current context.
 *
 * @return array The remaining graph pieces.
 */
function remove_breadcrumbs_from_schema( $pieces, $context ) {
    return \array_filter( $pieces, function( $piece ) {
        return ! $piece instanceof \Yoast\WP\SEO\Generators\Schema\Breadcrumb;
    } );
}

/**
 * Removes the breadcrumb property from the WebPage piece.
 *
 * @param array $data The WebPage's properties.
 *
 * @return array The modified WebPage properties.
 */
function remove_breadcrumbs_property_from_webpage( $data ) {
    if (array_key_exists('breadcrumb', $data)) {
        unset($data['breadcrumb']);
    }
    return $data;
}